==> owncloud-4.5.13.tar.bz2: owncloud/apps/calendar/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Kaikki kalenterit eivät ole täysin välitallennettu",
"Everything seems to be completely cached" => "Kaikki on ilmeisesti tallennettu välimuistiin",
"No calendars found." => "Kalentereita ei löytynyt",
"No events found." => "Tapahtumia ei löytynyt.",
"Wrong calendar" => "Väärä kalenteri",
"The file contained either no events or all events are already saved in your calendar." => "Tiedosto ei joko sisältänyt tapahtumia tai vaihtoehtoisesti kaikki tapahtumat on jo tallennettu kalenteriisi.",
"events has been saved in the new calendar" => "tapahtumat on tallennettu uuteen kalenteriin",
"Import failed" => "Tuonti epäonnistui",
"events has been saved in your calendar" => "tapahtumaa on tallennettu kalenteriisi",
"New Timezone:" => "Uusi aikavyöhyke:",
"Timezone changed" => "Aikavyöhyke vaihdettu",
"Invalid request" => "Virheellinen pyyntö",
"Calendar" => "Kalenteri",
"Deletion failed" => "Poisto epäonnistui",
"user" => "käyttäjä",
"group" => "ryhmä",
"Editable" => "Muoktattava",
"Shareable" => "Jaettavissa",
"Deletable" => "Poistettavissa",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "Syntymäpäivä",
"Business" => "Työ",
"Call" => "Ota yhteyttä",
"Clients" => "Asiakkaat",
"Deliverer" => "Toimittaja",
"Holidays" => "Vapaapäivät",
"Ideas" => "Ideat",
"Journey" => "Matkustus",
"Jubilee" => "Vuosipäivät",
"Meeting" => "Tapaamiset",
"Other" => "Muut",
"Personal" => "Henkilökohtainen",
"Projects" => "Projektit",
"Questions" => "Kysymykset",
"Work" => "Työ",
"by" => "toimesta:",
"unnamed" => "nimetön",
"You do not have the permissions to update this calendar." => "Käyttöoikeutesi eivät riitä tämän kalenterin päivittämiseen.",
"You do not have the permissions to delete this calendar." => "Käyttöoikeutesi eivät riitä tämän kalenterin poistamiseen.",
"You do not have the permissions to add to this calendar." => "Käyttöoikeutesi eivät riitä lisäämiseen tähän kalenteriin.",
"New Calendar" => "Uusi kalenteri",
"You do not have the permissions to add events to this calendar." => "Käyttöoikeutesi eivät riitä tapahtumien lisäämiseen tähän kalenteriin.",
"You do not have the permissions to edit this event." => "Käyttöoikeutesi eivät riitä tämän tapahtuman muokkaukseen.",
"You do not have the permissions to delete this event." => "Käyttöoikeutesi eivät riitä tämän tapahtuman poistamiseen.",
"Does not repeat" => "Ei toistoa",
"Daily" => "Päivittäin",
"Weekly" => "Viikottain",
"Every Weekday" => "Arkipäivisin",
"Bi-Weekly" => "Joka toinen viikko",
"Monthly" => "Kuukausittain",
"Yearly" => "Vuosittain",
"never" => "Ei koskaan",
"by occurrences" => "esiintymisten mukaan",
"by date" => "päivämäärän mukaan",
"by monthday" => "kuukaudenpäivän mukaan",
"by weekday" => "viikonpäivän mukaan",
"Monday" => "Maanantai",
"Tuesday" => "Tiistai",
"Wednesday" => "Keskiviikko",
"Thursday" => "Torstai",
"Friday" => "Perjantai",
"Saturday" => "Lauantai",
"Sunday" => "Sunnuntai",
"events week of month" => "tapahtumat kuukauden viikolla",
"first" => "ensimmäinen",
"second" => "toinen",
"third" => "kolmas",
"fourth" => "neljäs",
"fifth" => "viides",
"last" => "viimeinen",
"January" => "Tammikuu",
"February" => "Helmikuu",
"March" => "Maaliskuu",
"April" => "Huhtikuu",
"May" => "Toukokuu",
"June" => "Kesäkuu",
"July" => "Heinäkuu",
"August" => "Elokuu",
"September" => "Syyskuu",
"October" => "Lokakuu",
"November" => "Marraskuu",
"December" => "Joulukuu",
"by events date" => "tapahtumien päivämäärän mukaan",
"by yearday(s)" => "vuoden päivän mukaan",
"by weeknumber(s)" => "viikkonumero(ide)n mukaan",
"by day and month" => "päivän ja kuukauden mukaan",
"Date" => "Päivämäärä",
"Cal." => "Kal.",
"Sun." => "Su",
"Mon." => "Ma",
"Tue." => "Ti",
"Wed." => "Ke",
"Thu." => "To",
"Fri." => "Pe",
"Sat." => "La",
"Jan." => "Tammi",
"Feb." => "Helmi",
"Mar." => "Maalis",
"Apr." => "Huhti",
"May." => "Touko",
"Jun." => "Kesä",
"Jul." => "Heinä",
"Aug." => "Elo",
"Sep." => "Syys",
"Oct." => "Loka",
"Nov." => "Marras",
"Dec." => "Joulu",
"All day" => "Koko päivä",
"Missing fields" => "Puuttuvat kentät",
"Title" => "Otsikko",
"From Date" => "Päivämäärästä",
"From Time" => "Alkuaika",
"To Date" => "Päivämäärään",
"To Time" => "Loppuaika",
"The event ends before it starts" => "Tapahtuma päättyy ennen alkamistaan",
"There was a database fail" => "Tapahtui tietokantavirhe",
"Week" => "Viikko",
"Month" => "Kuukausi",
"List" => "Lista",
"Today" => "Tänään",
"Calendars" => "Kalenterit",
"Settings" => "Asetukset",
"Your calendars" => "Omat kalenterisi",
"CalDav Link" => "CalDav-linkki",
"Share Calendar" => "Jaa kalenteri",
"Download" => "Lataa",
"Edit" => "Muokkaa",
"Delete" => "Poista",
"shared with you by" => "kanssasi jaettu",
"New calendar" => "Uusi kalenteri",
"Edit calendar" => "Muokkaa kalenteria",
"Displayname" => "Kalenterin nimi",
"Active" => "Aktiivinen",
"Calendar color" => "Kalenterin väri",
"Save" => "Tallenna",
"Submit" => "Talleta",
"Cancel" => "Peru",
"Edit an event" => "Muokkaa tapahtumaa",
"Export" => "Vie",
"Eventinfo" => "Tapahtumatiedot",
"Repeating" => "Toisto",
"Alarm" => "Hälytys",
"Attendees" => "Osallistujat",
"Share" => "Jaa",
"Title of the Event" => "Tapahtuman otsikko",
"Category" => "Luokka",
"Separate categories with commas" => "Erota luokat pilkuilla",
"Edit categories" => "Muokkaa luokkia",
"All Day Event" => "Koko päivän tapahtuma",
"From" => "Alkaa",
"To" => "Päättyy",
"Advanced options" => "Tarkemmat asetukset",
"Location" => "Sijainti",
"Location of the Event" => "Tapahtuman sijainti",
"Description" => "Kuvaus",
"Description of the Event" => "Tapahtuman kuvaus",
"Repeat" => "Toisto",
"Advanced" => "Edistynyt",
"Select weekdays" => "Valitse viikonpäivät",
"Select days" => "Valitse päivät",
"and the events day of year." => "ja tapahtumien päivä vuodessa.",
"and the events day of month." => "ja tapahtumien päivä kuukaudessa.",
"Select months" => "Valitse kuukaudet",
"Select weeks" => "Valitse viikot",
"and the events week of year." => "ja tapahtumien viikko vuodessa.",
"Interval" => "Intervalli",
"End" => "Loppu",
"occurrences" => "esiintymät",
"create a new calendar" => "luo uusi kalenteri",
"Import a calendar file" => "Tuo kalenteritiedosto",
"Please choose a calendar" => "Valitse kalenteri",
"Name of new calendar" => "Uuden kalenterin nimi",
"Take an available name!" => "Ota nimi, joka on käytettävissä!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Samalla nimellä on jo olemassa kalenteri. Jos jatkat kaikesta huolimatta, kalenterit yhdistetään.",
"Import" => "Tuo",
"Close Dialog" => "Sulje ikkuna",
"Create a new event" => "Luo uusi tapahtuma",
"Share with:" => "Jaa:",
"Shared with" => "Jaettu",
"Unshare" => "Poista jakaminen",
"Nobody" => "Ei kukaan",
"Shared via calendar" => "Jaettu kalenterin kanssa",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "HUOMAA: Kalenterissa jaettujen tapahtumien toimenpiteet vaikuttavat koko kalenterin jakamiseen. ",
"View an event" => "Avaa tapahtuma",
"No categories selected" => "Luokkia ei ole valittu",
"of" => " ",
"at" => " ",
"General" => "Yleiset",
"Timezone" => "Aikavyöhyke",
"Update timezone automatically" => "Päivitä aikavyöhykkeet automaattisesti",
"Time format" => "Ajan näyttömuoto",
"24h" => "24 tuntia",
"12h" => "12 tuntia",
"Start week on" => "Viikon alkamispäivä",
"Cache" => "Välimuisti",
"Clear cache for repeating events" => "Tyhjennä välimuisti toistuvista tapahtumista",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Kalenterin CalDAV-synkronointiosoitteet",
"more info" => "lisätietoja",
"Primary address (Kontact et al)" => "Ensisijainen osoite (Kontact ja muut vastaavat)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "iCalendar linkit, jotka ovat vain lukuoikeuksilla"
);

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Kaikki kalenterit eivät ole täysin välitallennettu",
"Everything seems to be completely cached" => "Kaikki on ilmeisesti tallennettu välimuistiin",
"No calendars found." => "Kalentereita ei löytynyt",
"No events found." => "Tapahtumia ei löytynyt.",
"Wrong calendar" => "Väärä kalenteri",
"You do not have the permissions to edit this event." => "Käyttöoikeutesi eivät riitä tämän tapahtuman muokkaukseen.",
"The file contained either no events or all events are already saved in your calendar." => "Tiedosto ei joko sisältänyt tapahtumia tai vaihtoehtoisesti kaikki tapahtumat on jo tallennettu kalenteriisi.",
"events have been saved in the new calendar" => "tapahtumaa on tallennettu uuteen kalenteriisi",
"Import failed" => "Tuonti epäonnistui",
"events have been saved in your calendar" => "tapahtumaa on tallennettu kalenteriisi",
"New Timezone:" => "Uusi aikavyöhyke:",
"Timezone changed" => "Aikavyöhyke vaihdettu",
"Invalid request" => "Virheellinen pyyntö",
"Calendar" => "Kalenteri",
"Deletion failed" => "Poisto epäonnistui",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d. MMMM'ta'[ yyyy]{ – [ddd d.] MMMM'ta' yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d. MMMM'ta'[ yyyy] klo HH:mm{ – [ ddd d. MMMM'ta' yyyy] klo HH:mm}",
"group" => "ryhmä",
"can edit" => "voi muokata",
"can share" => "jaa",
"ddd" => "ddd",
"ddd M/d" => "ddd d.M.",
"dddd M/d" => "dddd d.M.",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "KKK p[ vvvv]{ '–'[ KKK] p vvvv}",
"dddd, MMM d, yyyy" => "dddd, d. MMMM'ta' yyyy",
"Sunday" => "sunnuntai",
"Monday" => "maanantai",
"Tuesday" => "tiistai",
"Wednesday" => "keskiviikko",
"Thursday" => "torstai",
"Friday" => "perjantai",
"Saturday" => "lauantai",
"Sun." => "su",
"Mon." => "ma",
"Tue." => "ti",
"Wed." => "ke",
"Thu." => "to",
"Fri." => "pe",
"Sat." => "la",
"January" => "tammikuu",
"February" => "helmikuu",
"March" => "maaliskuu",
"April" => "huhtikuu",
"May" => "toukokuu",
"June" => "kesäkuu",
"July" => "heinäkuu",
"August" => "elokuu",
"September" => "syyskuu",
"October" => "lokakuu",
"November" => "marraskuu",
"December" => "joulukuu",
"Jan." => "tammi",
"Feb." => "helmi",
"Mar." => "maalis",
"Apr." => "huhti",
"May." => "touko",
"Jun." => "kesä",
"Jul." => "heinä",
"Aug." => "elo",
"Sep." => "syys",
"Oct." => "loka",
"Nov." => "marras",
"Dec." => "joulu",
"All day" => "Koko päivä",
"New Calendar" => "Uusi kalenteri",
"Missing or invalid fields" => "Puuttuvia tai virheellisiä kenttiä",
"Title" => "Otsikko",
"From Date" => "Päivämäärästä",
"From Time" => "Alkuaika",
"To Date" => "Päivämäärään",
"To Time" => "Loppuaika",
"The event ends before it starts" => "Tapahtuma päättyy ennen alkamistaan",
"There was a database fail" => "Tapahtui tietokantavirhe",
"Interval is not valid. It must be a positive integer!" => "Aikaväli on virheellinen. Arvon tulee olla positiivinen kokonaisluku!",
"Birthday" => "Syntymäpäivä",
"Business" => "Työ",
"Call" => "Ota yhteyttä",
"Clients" => "Asiakkaat",
"Deliverer" => "Toimittaja",
"Holidays" => "Vapaapäivät",
"Ideas" => "Ideat",
"Journey" => "Matkustus",
"Jubilee" => "Vuosipäivät",
"Meeting" => "Tapaamiset",
"Other" => "Muut",
"Personal" => "Henkilökohtainen",
"Projects" => "Projektit",
"Questions" => "Kysymykset",
"Work" => "Työ",
"by" => "toimesta:",
"unnamed" => "nimetön",
"You do not have the permissions to update this calendar." => "Käyttöoikeutesi eivät riitä tämän kalenterin päivittämiseen.",
"You do not have the permissions to delete this calendar." => "Käyttöoikeutesi eivät riitä tämän kalenterin poistamiseen.",
"You do not have the permissions to add to this calendar." => "Käyttöoikeutesi eivät riitä lisäämiseen tähän kalenteriin.",
"You do not have the permissions to add events to this calendar." => "Käyttöoikeutesi eivät riitä tapahtumien lisäämiseen tähän kalenteriin.",
"You cannot add non-public events to a shared calendar." => "Et voi lisätä ei-julkisia tapahtumia jaettuun kalenteriin.",
"You do not have the permissions to delete this event." => "Käyttöoikeutesi eivät riitä tämän tapahtuman poistamiseen.",
"Busy" => "Kiireinen",
"Show full event" => "Näytä koko tapahtuma",
"Show only busy" => "Näytä vain varatut",
"Hide event" => "Piilota tapahtuma",
"Does not repeat" => "Ei toistoa",
"Daily" => "Päivittäin",
"Weekly" => "Viikottain",
"Every Weekday" => "Arkipäivisin",
"Bi-Weekly" => "Joka toinen viikko",
"Monthly" => "Kuukausittain",
"Yearly" => "Vuosittain",
"never" => "Ei koskaan",
"by occurrences" => "esiintymisten mukaan",
"by date" => "päivämäärän mukaan",
"by monthday" => "kuukaudenpäivän mukaan",
"by weekday" => "viikonpäivän mukaan",
"events week of month" => "tapahtumat kuukauden viikolla",
"first" => "ensimmäinen",
"second" => "toinen",
"third" => "kolmas",
"fourth" => "neljäs",
"fifth" => "viides",
"last" => "viimeinen",
"by events date" => "tapahtumien päivämäärän mukaan",
"by yearday(s)" => "vuoden päivän mukaan",
"by weeknumber(s)" => "viikkonumero(ide)n mukaan",
"by day and month" => "päivän ja kuukauden mukaan",
"Contact birthdays" => "Synttärit",
"Date" => "Päivämäärä",
"Cal." => "Kal.",
"Day" => "Päivä",
"Week" => "Viikko",
"Month" => "Kuukausi",
"Today" => "Tänään",
"CalDav Link" => "CalDav-linkki",
"Timezone" => "Aikavyöhyke",
"Update timezone automatically" => "Päivitä aikavyöhykkeet automaattisesti",
"Time format" => "Ajan näyttömuoto",
"24h" => "24-tuntinen",
"12h" => "12-tuntinen",
"Start week on" => "Viikon alkamispäivä",
"Cache" => "Välimuisti",
"Clear cache for repeating events" => "Tyhjennä välimuisti toistuvista tapahtumista",
"Primary CalDAV address" => "Ensisijainen CalDAV-osoite",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV -osoite",
"Share Calendar" => "Jaa kalenteri",
"Download" => "Lataa",
"Edit" => "Muokkaa",
"Delete" => "Poista",
"New calendar" => "Uusi kalenteri",
"Edit calendar" => "Muokkaa kalenteria",
"Edit event" => "Muokkaa tapahtumaa",
"Save event" => "Tallenna tapahtuma",
"Delete event" => "Poista tapahtuma",
"Eventinfo" => "Tapahtumatiedot",
"Repeating" => "Toisto",
"Alarm" => "Hälytys",
"Attendees" => "Osallistujat",
"Share" => "Jaa",
"Title of the Event" => "Tapahtuman otsikko",
"from" => "Syöte:",
"to" => "- ",
"All Day Event" => "Koko päivän tapahtuma",
"Advanced options" => "Tarkemmat asetukset",
"Location" => "Sijainti",
"Categories (separate by comma)" => "Luokat (erottele pilkuin)",
"Edit categories" => "Muokkaa luokkia",
"Description" => "Kuvaus",
"Export event" => "Vie tapahtuma",
"Repeat" => "Toisto",
"Advanced" => "Lisäasetukset",
"Select weekdays" => "Valitse viikonpäivät",
"Select days" => "Valitse päivät",
"and the events day of year." => "ja tapahtumien päivä vuodessa.",
"and the events day of month." => "ja tapahtumien päivä kuukaudessa.",
"Select months" => "Valitse kuukaudet",
"Select weeks" => "Valitse viikot",
"and the events week of year." => "ja tapahtumien viikko vuodessa.",
"Interval" => "Aikaväli",
"End" => "Loppu",
"occurrences" => "esiintymät",
"Visibility to people shared with" => "Näkyvissä vain jaetuille",
"create a new calendar" => "luo uusi kalenteri",
"Import a calendar file" => "Tuo kalenteritiedosto",
"Please choose a calendar" => "Valitse kalenteri",
"Name of new calendar" => "Uuden kalenterin nimi",
"Take an available name!" => "Ota nimi, joka on käytettävissä!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Samalla nimellä on jo olemassa kalenteri. Jos jatkat kaikesta huolimatta, kalenterit yhdistetään.",
"Remove all events from the selected calendar" => "Poista kaikki tapahtumat valitusta kalenterista",
"Import" => "Tuo",
"Close Dialog" => "Sulje ikkuna",
"Create a new event" => "Luo uusi tapahtuma",
"Create event" => "Luo tapahtuma",
"Share with user or group" => "Jaa käyttäjän tai ryhmän kanssa",
"Unshare" => "Poista jakaminen",
"Not shared with anyone" => "Ei jaettu kenenkään kanssa",
"Send Email" => "Lähetä sähköpostia",
"Shared via calendar" => "Jaettu kalenterin kanssa",
"Not shared with anyone via calendar" => "Ei jaettu kenenkään kanssa kalenterin kautta",
"View an event" => "Avaa tapahtuma",
"Category" => "Luokka",
"No categories selected" => "Luokkia ei ole valittu",
"%s of %s" => "%s/%s",
"Access Class" => "Pääsyluokka",
"From" => "Alkaa",
"at" => " ",
"To" => "Päättyy"
);
